#ifndef NT2_CORE_INCLUDE_FUNCTIONS_OUTER_FOLD_HPP_INCLUDED
#define NT2_CORE_INCLUDE_FUNCTIONS_OUTER_FOLD_HPP_INCLUDED

#include <nt2/core/functions/outer_fold.hpp>
#include <nt2/core/functions/scalar/outer_fold.hpp>
#include <nt2/core/functions/shared_memory/outer_fold.hpp>
#include <nt2/core/functions/simd/outer_fold.hpp>

#endif
